PageRankAnchorSelection
=======================

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: PageRankAnchorSelection
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~PageRankAnchorSelection.extra_repr
      ~PageRankAnchorSelection.rank

   .. rubric:: Methods Documentation

   .. automethod:: extra_repr
   .. automethod:: rank
